@@ -46,10 +46,11 @@ class Model(nn.Module):
                 'prob_list': []
             }
             start = batch_data['start'][0]
-            logit_prob = softmax(prediction_scores[0][start], dim=0).data.tolist()
-            prob_result = {self.tokenizer.convert_ids_to_tokens(id): prob for id, prob in enumerate(logit_prob)}
-            prob_result = sorted(prob_result.items(), key=lambda x: x[1], reverse=True)
-            result_dict['prob_list'].append(sorted(logit_prob, reverse=True))
+            logit_prob = softmax(prediction_scores[0][start], dim=0)
+            topK = torch.topk(logit_prob, 50)
+            prob_result = [(self.tokenizer.convert_ids_to_tokens(id), prob) for prob, id in
+                           zip(topK.values.data.tolist(), topK.indices.data.tolist())]
+            result_dict['prob_list'].append(logit_prob.data.tolist())
             result_dict['label_prob_all'].append(prob_result)
             result_dict['label_map'].append(prob_result[0])
             outputs = result_dict
